#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 pantry
version:              0.8.2.2
visibility:           public
id:                   pantry-0.8.2.2-9C5OBDLvrqMIn6OcjJfdFr
key:                  pantry-0.8.2.2-9C5OBDLvrqMIn6OcjJfdFr
license:              BSD-3-Clause
copyright:            2018-2022 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/commercialhaskell/pantry#readme
synopsis:             Content addressable Haskell package management
description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/pantry#readme>

category:             Development
abi:                  a555c051d099cbc67232ba1f0faf5ce0
exposed:              True
exposed-modules:
    Pantry Pantry.Internal Pantry.Internal.AesonExtended
    Pantry.Internal.Companion Pantry.Internal.Stackage
    Pantry.Internal.StaticBytes Pantry.SHA256

hidden-modules:
    Hackage.Security.Client.Repository.HttpLib.HttpClient
    Pantry.Archive Pantry.HTTP Pantry.HPack Pantry.Hackage Pantry.Repo
    Pantry.SQLite Pantry.Storage Pantry.Casa Pantry.Tree Pantry.Types
    System.IsWindows

import-dirs:          /usr/lib/ghc-9.6.6/site-local/pantry-0.8.2.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/pantry-0.8.2.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/pantry-0.8.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pantry
hs-libraries:         HSpantry-0.8.2.2-9C5OBDLvrqMIn6OcjJfdFr
depends:
    Cabal-3.10.3.0 aeson-2.2.0.0-4qLATSA6nfj1RfgXH6DMKK
    ansi-terminal-1.1-6H4MdlQ9LS5JB7dL181Y6t base-4.18.2.1
    bytestring-0.11.5.3 casa-client-0.0.3-HtP0tr4MZUTA0HIehdQtrT
    casa-types-0.0.3-8wmyL69Ed2oCxx1uuEI1lE
    conduit-1.3.6.1-4cc2yOSL2sy5iK6rZQd5vm
    conduit-extra-1.3.8-KyGJKsBlxeR6aLyGVSa94z containers-0.6.7
    crypton-1.0.4-DGMKyUhI3LiKWt7ay9qYrG
    crypton-conduit-0.2.3-FVD4oa2ofTg5d21ycTadwB
    digest-0.0.2.1-JWOwjMkQwx5F9nVaVojfVV
    filelock-0.1.1.8-5yKiUxUc3R4Cn5BuwIn6Cx
    generic-deriving-1.14.6-89W8tWKmocDFxpcsvKtVjK
    hackage-security-0.6.3.2-CB3Wrsd9Zaj3qQCy2bMoEY
    hpack-0.38.0-GBgYgDWrKma9qYYXp6gKtE
    http-client-0.7.19-4rucZD6prn1Bn7NkqCpiFR
    http-client-tls-0.3.6.4-LhFztqm7Yl955SnS7vNn0b
    http-conduit-2.3.9.1-3cMmWLkkkkTQL61v9H7Y4
    http-download-0.2.1.0-4Ngrp4jnbYC4HpgYYpo77q
    http-types-0.12.4-Hj8jLUhN6rtnIgKEy5ynr
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    network-uri-2.6.4.2-3U0FvLc2coZ6tqjF5PGDly
    path-0.9.6-CG6breuY1qpGvStm5q67Gc
    path-io-1.8.2-J3oPz6svUjz5wY9ouZNltz
    persistent-2.14.5.2-3iklR6qVhbcHkfvtZeVIbd
    persistent-sqlite-2.13.1.1-DfjIP0Qysc26cRpm21EvbJ
    primitive-0.9.1.0-3wcULVX324m4b7zw32DKNg
    resourcet-1.2.6-Dhf0zTJRCL3LnKPExtEFW6
    rio-0.1.24.0-8z6Z4xtsejOAYZQptyiBbv
    rio-orphans-0.1.2.0-4mEWsRyFVaN2y2qAJ4YGWZ
    rio-prettyprint-0.1.8.0-3GH2Xko1no3DAKBMoLmHK2
    tar-conduit-0.4.1-Igs0d4Yn08h6oafM4jnh9u text-2.0.2
    text-metrics-0.3.3-3AOpgZ4OOzO8hscaLL3xTy time-1.12.2
    transformers-0.6.1.0 unix-compat-0.7.4.1-DqDzbwuaouv1yXLtKQLq3q
    unliftio-0.2.25.1-2Z0SKAH7tah9jbYwGNfwFX
    unordered-containers-0.2.20.1-I6eyTXb69D2BhxejMtPouo
    vector-0.13.2.0-KFVS0U8K6eML5O0P7tVbRi
    yaml-0.11.11.2-BS6mG9zOsXWGQgGFfufno4
    zip-archive-0.4.3.2-1XeMNWl5bCBHGBNkq6CyGn

haddock-interfaces:   /usr/share/doc/haskell-pantry/html/pantry.haddock
haddock-html:         /usr/share/doc/haskell-pantry/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

